@@ -30,7 +30,7 @@ enum class binary_sub_type : std::uint8_t;
 namespace types {
 struct b_eod;
 struct b_double;
-struct b_utf8;
+struct b_string;
 struct b_document;
 struct b_array;
 struct b_binary;
@@ -145,13 +145,24 @@ class BSONCXX_API element {
     types::b_double get_double() const;
 
     ///
-    /// Getter for elements of the b_utf8 type.
+    /// Getter for elements of the b_string type.
     ///
-    /// @throws bsoncxx::exception if this element is not a b_utf8.
+    /// @deprecated use document::element::get_string() instead.
+    ///
+    /// @throws bsoncxx::exception if this element is not a b_string.
     ///
     /// @return the element's value.
     ///
-    types::b_utf8 get_utf8() const;
+    BSONCXX_DEPRECATED types::b_string get_utf8() const;
+
+    ///
+    /// Getter for elements of the b_string type.
+    ///
+    /// @throws bsoncxx::exception if this element is not a b_string.
+    ///
+    /// @return the element's value.
+    ///
+    types::b_string get_string() const;
 
     ///
     /// Getter for elements of the b_document type.
@@ -399,6 +410,36 @@ class BSONCXX_API element {
     std::uint32_t _keylen;
 };
 
+///
+/// @{
+///
+/// Convenience methods to compare for equality against a bson_value.
+///
+/// Returns true if this element contains a bson_value that matches.
+///
+/// @relates element
+///
+BSONCXX_API bool BSONCXX_CALL operator==(const element& elem, const types::bson_value::view& v);
+BSONCXX_API bool BSONCXX_CALL operator==(const types::bson_value::view& v, const element& elem);
+///
+/// @}
+///
+
+///
+/// @{
+///
+/// Convenience methods to compare for equality against a bson_value.
+///
+/// Returns false if this element contains a bson_value that matches.
+///
+/// @relates element
+///
+BSONCXX_API bool BSONCXX_CALL operator!=(const element& elem, const types::bson_value::view& v);
+BSONCXX_API bool BSONCXX_CALL operator!=(const types::bson_value::view& v, const element& elem);
+///
+/// @}
+///
+
 }  // namespace document
 
 BSONCXX_INLINE_NAMESPACE_END
