@@ -25,6 +25,9 @@
 namespace mongocxx {
 MONGOCXX_INLINE_NAMESPACE_BEGIN
 
+///
+/// Class supporting operations for MongoDB Client-Side Field Level Encryption.
+///
 class MONGOCXX_API client_encryption {
    public:
     ///
@@ -42,12 +45,25 @@ class MONGOCXX_API client_encryption {
     ///
     ~client_encryption() noexcept;
 
+    ///
+    /// Move-constructs a client_encryption object.
+    ///
+    client_encryption(client_encryption&&);
+
+    ///
+    /// Move-assigns a client_encryption object.
+    ///
+    client_encryption& operator=(client_encryption&&);
+
+    client_encryption(const client_encryption&) = delete;
+    client_encryption& operator=(const client_encryption&) = delete;
+
     ///
     /// Creates a new key document and inserts into the key vault collection.
     ///
     /// @param kms_provider
-    ///   A string identifying the KMS service to use to encrypt the datakey
-    ///   (must be "aws" or "local")
+    ///   A string identifying the KMS service to use to encrypt the datakey.
+    ///   Must be one of "aws", "azure", "gcp", "kmip", or "local".
     /// @param opts
     ///   Optional arguments, see options::data_key.
     ///
@@ -84,7 +100,7 @@ class MONGOCXX_API client_encryption {
     ///
     /// Decrypts an encrypted value (BSON binary of subtype 6).
     ///
-    /// @param
+    /// @param value
     ///   The encrypted value.
     ///
     /// @return The original BSON value.
