@@ -12,11 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include "helpers.hpp"
-
 #include <chrono>
 #include <string>
 
+#include "helpers.hpp"
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/document/element.hpp>
 #include <bsoncxx/json.hpp>
@@ -76,14 +75,15 @@ TEST_CASE("Collection", "[collection]") {
         read_concern rc{};
         rc.acknowledge_level(read_concern::level::k_majority);
 
-        collection_set_read_concern->interpose([&collection_set_rc_called](
-            ::mongoc_collection_t*, const ::mongoc_read_concern_t* rc_t) {
-            REQUIRE(rc_t);
-            const auto result = libmongoc::read_concern_get_level(rc_t);
-            REQUIRE(result);
-            REQUIRE(strcmp(result, "majority") == 0);
-            collection_set_rc_called = true;
-        });
+        collection_set_read_concern->interpose(
+            [&collection_set_rc_called](::mongoc_collection_t*,
+                                        const ::mongoc_read_concern_t* rc_t) {
+                REQUIRE(rc_t);
+                const auto result = libmongoc::read_concern_get_level(rc_t);
+                REQUIRE(result);
+                REQUIRE(strcmp(result, "majority") == 0);
+                collection_set_rc_called = true;
+            });
 
         mongo_coll.read_concern(rc);
         REQUIRE(collection_set_rc_called);
@@ -116,7 +116,7 @@ TEST_CASE("Collection", "[collection]") {
                 bsoncxx::document::view o(bson_get_data(options), options->len);
 
                 bsoncxx::stdx::string_view bar(
-                    p[0].get_document().value["$match"].get_document().value["foo"].get_utf8());
+                    p[0].get_document().value["$match"].get_document().value["foo"].get_string());
                 std::int32_t one(
                     p[1].get_document().value["$sort"].get_document().value["foo"].get_int32());
 
@@ -348,7 +348,7 @@ TEST_CASE("Collection", "[collection]") {
                         *expected_allow_partial_results);
             }
             if (expected_comment) {
-                REQUIRE(opts_view["comment"].get_utf8().value == *expected_comment);
+                REQUIRE(opts_view["comment"].get_string().value == *expected_comment);
             }
             if (expected_cursor_type) {
                 bsoncxx::document::element tailable = opts_view["tailable"];
@@ -369,7 +369,7 @@ TEST_CASE("Collection", "[collection]") {
                 }
             }
             if (expected_hint) {
-                REQUIRE(opts_view["hint"].get_utf8() == expected_hint->get_utf8());
+                REQUIRE(opts_view["hint"].get_string() == expected_hint->get_string());
             }
             if (expected_no_cursor_timeout) {
                 REQUIRE(opts_view["noCursorTimeout"].get_bool().value ==
@@ -598,7 +598,7 @@ TEST_CASE("Collection", "[collection]") {
                 }
 
                 if (expected_hint) {
-                    REQUIRE(options_view["hint"].get_utf8() == expected_hint->get_utf8());
+                    REQUIRE(options_view["hint"].get_string() == expected_hint->get_string());
                 } else {
                     REQUIRE(!options_view["hint"]);
                 }
@@ -723,7 +723,7 @@ TEST_CASE("Collection", "[collection]") {
                 }
 
                 if (expected_hint) {
-                    REQUIRE(options_view["hint"].get_utf8() == expected_hint->get_utf8());
+                    REQUIRE(options_view["hint"].get_string() == expected_hint->get_string());
                 } else {
                     REQUIRE(!options_view["hint"]);
                 }
@@ -806,7 +806,7 @@ TEST_CASE("Collection", "[collection]") {
                 }
 
                 if (expected_hint) {
-                    REQUIRE(options_view["hint"].get_utf8() == expected_hint->get_utf8());
+                    REQUIRE(options_view["hint"].get_string() == expected_hint->get_string());
                 } else {
                     REQUIRE(!options_view["hint"]);
                 }
@@ -861,15 +861,17 @@ TEST_CASE("Collection", "[collection]") {
 
         SECTION("Delete One", "[collection::delete_one]") {
             expected_order_setting = true;
-            bulk_operation_remove_one_with_opts->interpose([&](
-                mongoc_bulk_operation_t*, const bson_t* doc, const bson_t* options, bson_error_t*) {
+            bulk_operation_remove_one_with_opts->interpose([&](mongoc_bulk_operation_t*,
+                                                               const bson_t* doc,
+                                                               const bson_t* options,
+                                                               bson_error_t*) {
                 bulk_operation_op_called = true;
                 REQUIRE(bson_get_data(doc) == filter_doc.view().data());
 
                 bsoncxx::document::view options_view{bson_get_data(options), options->len};
                 if (expected_hint) {
                     CAPTURE(to_json(options_view));
-                    REQUIRE(options_view["hint"].get_utf8() == expected_hint->get_utf8());
+                    REQUIRE(options_view["hint"].get_string() == expected_hint->get_string());
                 } else {
                     REQUIRE(!options_view["hint"]);
                 }
@@ -904,15 +906,17 @@ TEST_CASE("Collection", "[collection]") {
 
         SECTION("Delete Many", "[collection::delete_many]") {
             expected_order_setting = true;
-            bulk_operation_remove_many_with_opts->interpose([&](
-                mongoc_bulk_operation_t*, const bson_t* doc, const bson_t* options, bson_error_t*) {
+            bulk_operation_remove_many_with_opts->interpose([&](mongoc_bulk_operation_t*,
+                                                                const bson_t* doc,
+                                                                const bson_t* options,
+                                                                bson_error_t*) {
                 bulk_operation_op_called = true;
                 REQUIRE(bson_get_data(doc) == filter_doc.view().data());
 
                 bsoncxx::document::view options_view{bson_get_data(options), options->len};
                 if (expected_hint) {
                     CAPTURE(to_json(options_view));
-                    REQUIRE(options_view["hint"].get_utf8() == expected_hint->get_utf8());
+                    REQUIRE(options_view["hint"].get_string() == expected_hint->get_string());
                 } else {
                     REQUIRE(!options_view["hint"]);
                 }
