@@ -13,7 +13,6 @@
 // limitations under the License.
 
 #include "helpers.hpp"
-
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/document/view.hpp>
 #include <bsoncxx/private/suppress_deprecation_warnings.hh>
@@ -132,7 +131,7 @@ TEST_CASE("create_collection can be exported to a document", "[create_collection
 
     document::element validationLevel{doc_view["validationLevel"]};
     REQUIRE(validationLevel);
-    REQUIRE(validationLevel.type() == type::k_utf8);
+    REQUIRE(validationLevel.type() == type::k_string);
     REQUIRE(bsoncxx::string::to_string(validationLevel.get_string().value) == "strict");
 
     document::element validationAction{doc_view["validationAction"]};
