@@ -12,14 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include "helpers.hpp"
-
 #include <chrono>
 
+#include "helpers.hpp"
 #include <bsoncxx/builder/basic/document.hpp>
-#include <bsoncxx/document/view.hpp>
 #include <bsoncxx/test_util/catch.hh>
-#include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/options/find.hpp>
 
